@@ -4,11 +4,8 @@ from collections import defaultdict
 
 import numpy as np
 
-from openmdao.approximation_schemes.approximation_scheme import ApproximationScheme, \
-    _gather_jac_results, _get_wrt_subjacs, _full_slice
-from openmdao.utils.general_utils import simple_warning
-from openmdao.utils.array_utils import sub2full_indices
-from openmdao.utils.coloring import Coloring
+from openmdao.warnings import issue_warning, DerivativesWarning
+from openmdao.approximation_schemes.approximation_scheme import ApproximationScheme
 
 
 class ComplexStep(ApproximationScheme):
@@ -61,11 +58,14 @@ class ComplexStep(ApproximationScheme):
         options.update(kwargs)
         options['vector'] = vector
 
-        key = (abs_key[1], options['step'], options['directional'])
-        self._exec_dict[key].append((abs_key, options))
+        wrt = abs_key[1]
+        if wrt in self._wrt_meta:
+            self._wrt_meta[wrt].update(options)
+        else:
+            self._wrt_meta[wrt] = options
         self._reset()  # force later regen of approx_groups
 
-    def _get_approx_data(self, system, data):
+    def _get_approx_data(self, system, wrt, meta):
         """
         Given approximation metadata, compute necessary delta for complex step.
 
@@ -73,19 +73,21 @@ class ComplexStep(ApproximationScheme):
         ----------
         system : System
             System whose derivatives are being approximated.
-        data : tuple
-            Tuple of the form (wrt, delta, directional)
+        wrt : str
+            Name of wrt variable.
+        meta : dict
+            Metadata dict.
 
         Returns
         -------
         float
             Delta needed for complex step perturbation.
         """
-        _, delta, _ = data
-        delta *= 1j
-        return delta
+        step = meta['step']
+        step *= 1j
+        return step
 
-    def compute_approximations(self, system, jac, total=False):
+    def compute_approx_col_iter(self, system, total=False, under_cs=False):
         """
         Execute the system to compute the approximate sub-Jacobians.
 
@@ -93,12 +95,12 @@ class ComplexStep(ApproximationScheme):
         ----------
         system : System
             System on which the execution is run.
-        jac : dict-like
-            Approximations are stored in the given dict-like object.
         total : bool
             If True total derivatives are being approximated, else partials.
+        under_cs : bool
+            True if we're currently under complex step at a higher level.
         """
-        if not self._exec_dict:
+        if not self._wrt_meta:
             return
 
         if system.under_complex_step:
@@ -107,16 +109,15 @@ class ComplexStep(ApproximationScheme):
             if not self._fd:
                 from openmdao.approximation_schemes.finite_difference import FiniteDifference
 
-                msg = "Nested complex step detected. Finite difference will be used for '%s'."
-                simple_warning(msg % system.pathname)
+                issue_warning("Nested complex step detected. Finite difference will be used.",
+                              prefix=system.pathname, category=DerivativesWarning)
 
                 fd = self._fd = FiniteDifference()
                 empty = {}
-                for lst in self._exec_dict.values():
-                    for apprx in lst:
-                        fd.add_approximation(apprx[0], system, empty)
+                for wrt in self._wrt_meta:
+                    fd.add_approximation(wrt, system, empty)
 
-            self._fd.compute_approximations(system, jac, total=total)
+            yield from self._fd.compute_approx_col_iter(system, total=total)
             return
 
         saved_inputs = system._inputs._get_data().copy()
@@ -129,10 +130,11 @@ class ComplexStep(ApproximationScheme):
         # Turn on complex step.
         system._set_complex_step_mode(True)
 
-        self._compute_approximations(system, jac, total, under_cs=True)
-
-        # Turn off complex step.
-        system._set_complex_step_mode(False)
+        try:
+            yield from self._compute_approx_col_iter(system, total, under_cs=True)
+        finally:
+            # Turn off complex step.
+            system._set_complex_step_mode(False)
 
         system._inputs.set_val(saved_inputs)
         system._outputs.set_val(saved_outputs)
@@ -144,7 +146,7 @@ class ComplexStep(ApproximationScheme):
 
         Parameters
         ----------
-        delta :  complex
+        delta : complex
             Complex number used to compute the multiplier.
 
         Returns
@@ -189,8 +191,8 @@ class ComplexStep(ApproximationScheme):
 
         Returns
         -------
-        Vector
-            Copy of the results from running the perturbed system.
+        ndarray
+            Copy of the outputs or residuals array after running the perturbed system.
         """
         for vec, idxs in idx_info:
             if vec is not None:
@@ -198,10 +200,10 @@ class ComplexStep(ApproximationScheme):
 
         if total:
             system.run_solve_nonlinear()
-            result_array[:] = system._outputs._data
+            result_array[:] = system._outputs.asarray()
         else:
             system.run_apply_nonlinear()
-            result_array[:] = system._residuals._data
+            result_array[:] = system._residuals.asarray()
 
         for vec, idxs in idx_info:
             if vec is not None:
