@@ -6,7 +6,7 @@ from itertools import product
 
 import numpy as np
 from numpy import ndarray, isscalar, atleast_1d, atleast_2d, promote_types
-from scipy.sparse import issparse
+from scipy.sparse import issparse, coo_matrix
 
 from openmdao.core.system import System, _supported_methods, _DEFAULT_COLORING_META, \
     global_meta_names
@@ -17,10 +17,11 @@ from openmdao.utils.units import simplify_unit
 from openmdao.utils.name_maps import rel_key2abs_key, abs_key2rel_key, rel_name2abs_name
 from openmdao.utils.mpi import MPI
 from openmdao.utils.general_utils import format_as_float_or_array, ensure_compatible, \
-    find_matches, simple_warning, make_set, _is_slicer_op, warn_deprecation, convert_src_inds, \
+    find_matches, make_set, _is_slicer_op, convert_src_inds, \
     _slice_indices
 import openmdao.utils.coloring as coloring_mod
-
+from openmdao.warnings import issue_warning, MPIWarning, DistributedComponentWarning, \
+    DerivativesWarning, UnusedOptionWarning, warn_deprecation
 
 _forbidden_chars = ['.', '*', '?', '!', '[', ']']
 _whitespace = set([' ', '\t', '\r', '\n'])
@@ -108,8 +109,15 @@ class Component(System):
         super()._declare_options()
 
         self.options.declare('distributed', types=bool, default=False,
-                             desc='True if the component has variables that are distributed '
-                                  'across multiple processes.')
+                             desc='True if ALL variables in this component are distributed '
+                                  'across multiple processes.',
+                             deprecation="The 'distributed' option has been deprecated. Individual "
+                                         "inputs and outputs should be set as distributed instead,"
+                                         " using calls to add_input() or add_output().")
+        self.options.declare('run_root_only', types=bool, default=False,
+                             desc='If True, call compute/compute_partials/linearize/apply_linear/'
+                                  'apply_nonlinear/compute_jacvec_product only on '
+                                  'rank 0 and broadcast the results to the other ranks.')
 
     def setup(self):
         """
@@ -148,19 +156,27 @@ class Component(System):
             if comm.size > 1:
                 comm = self._setup_par_fd_procs(comm)
             elif not MPI:
-                msg = ("%s: MPI is not active but num_par_fd = %d. No parallel finite difference "
-                       "will be performed." % (self.msginfo, self._num_par_fd))
-                simple_warning(msg)
+                issue_warning(f"MPI is not active but num_par_fd = {self._num_par_fd}. No parallel "
+                              "finite difference will be performed.",
+                              prefix=self.msginfo, category=MPIWarning)
+                self._num_par_fd = 1
 
         self.comm = comm
+        nprocs = comm.size
 
         # Clear out old variable information so that we can call setup on the component.
         self._var_rel_names = {'input': [], 'output': []}
         self._var_rel2meta = {}
+        if comm.size == 1:
+            self._has_distrib_vars = False
 
-        # reset shape if any dynamic shape parameters are set in case this is a resetup
-        # NOTE: this is necessary because we allow variables to be added in __init__.
         for meta in self._static_var_rel2meta.values():
+            # variable isn't distributed if we're only running on 1 proc
+            if nprocs == 1 and 'distributed' in meta and meta['distributed']:
+                meta['distributed'] = False
+
+            # reset shape if any dynamic shape parameters are set in case this is a resetup
+            # NOTE: this is necessary because we allow variables to be added in __init__.
             if 'shape_by_conn' in meta and (meta['shape_by_conn'] or
                                             meta['copy_shape'] is not None):
                 meta['shape'] = None
@@ -173,20 +189,23 @@ class Component(System):
         self._var_rel2meta.update(self._static_var_rel2meta)
         for io in ['input', 'output']:
             self._var_rel_names[io].extend(self._static_var_rel_names[io])
+
         self.setup()
+        self._setup_check()
 
         self._set_vector_class()
 
     def _set_vector_class(self):
-        if self.options['distributed']:
+        if self._has_distrib_vars:
             dist_vec_class = self._problem_meta['distributed_vector_class']
             if dist_vec_class is not None:
                 self._vector_class = dist_vec_class
             else:
-                simple_warning("The 'distributed' option is set to True for Component %s, "
-                               "but there is no distributed vector implementation (MPI/PETSc) "
-                               "available. The default non-distributed vectors will be used."
-                               % self.pathname)
+                issue_warning("Component contains distributed variables, "
+                              "but there is no distributed vector implementation (MPI/PETSc) "
+                              "available. The default non-distributed vectors will be used.",
+                              prefix=self.msginfo, category=DistributedComponentWarning)
+
                 self._vector_class = self._problem_meta['local_vector_class']
         else:
             self._vector_class = self._problem_meta['local_vector_class']
@@ -195,18 +214,19 @@ class Component(System):
         """
         Do any error checking on i/o configuration.
         """
-        # check here if declare_coloring was called during setup but declare_partials
-        # wasn't.  If declare partials wasn't called, call it with of='*' and wrt='*' so we'll
-        # have something to color.
+        # Check here if declare_coloring was called during setup but declare_partials wasn't.
+        # If declare partials wasn't called, call it with of='*' and wrt='*' so we'll have
+        # something to color.
         if self._coloring_info['coloring'] is not None:
             for key, meta in self._declared_partials.items():
                 if 'method' in meta and meta['method'] is not None:
                     break
             else:
                 method = self._coloring_info['method']
-                simple_warning("%s: declare_coloring or use_fixed_coloring was called but no approx"
-                               " partials were declared.  Declaring all partials as approximated "
-                               "using default metadata and method='%s'." % (self.msginfo, method))
+                issue_warning("declare_coloring or use_fixed_coloring was called but no approx"
+                              " partials were declared.  Declaring all partials as approximated "
+                              f"using default metadata and method='{method}'.", prefix=self.msginfo,
+                              category=DerivativesWarning)
                 self.declare_partials('*', '*', method=method)
 
         super()._configure_check()
@@ -353,9 +373,10 @@ class Component(System):
             self._declare_partials(of, wrt, dct)
 
         if self.matrix_free and self._subjacs_info:
-            simple_warning(f"{self.msginfo}: matrix free component has declared the following "
-                           f"partials: {sorted(self._subjacs_info)}, which will allocate "
-                           "(possibly unnecessary) memory for each of those sub-jacobians.")
+            issue_warning("matrix free component has declared the following "
+                          f"partials: {sorted(self._subjacs_info)}, which will allocate "
+                          "(possibly unnecessary) memory for each of those sub-jacobians.",
+                          prefix=self.msginfo, category=DerivativesWarning)
 
     def setup_partials(self):
         """
@@ -367,6 +388,29 @@ class Component(System):
         """
         pass
 
+    def _run_root_only(self):
+        """
+        Return the value of the run_root_only option and check for possible errors.
+
+        Returns
+        -------
+        bool
+            True if run_root_only is active.
+        """
+        if self.options['run_root_only']:
+            if self.comm.size > 1 or (self._full_comm is not None and self._full_comm.size > 1):
+                if self._has_distrib_vars:
+                    raise RuntimeError(f"{self.msginfo}: Can't set 'run_root_only' option when "
+                                       "a component has distributed variables.")
+                if self._num_par_fd > 1:
+                    raise RuntimeError(f"{self.msginfo}: Can't set 'run_root_only' option when "
+                                       "using parallel FD.")
+                if len(self._vec_names) > 2:
+                    raise RuntimeError(f"{self.msginfo}: Can't set 'run_root_only' option when "
+                                       "using parallel_deriv_color.")
+                return True
+        return False
+
     def _update_wrt_matches(self, info):
         """
         Determine the list of wrt variables that match the wildcard(s) given in declare_coloring.
@@ -378,17 +422,22 @@ class Component(System):
         """
         ofs, allwrt = self._get_partials_varlists()
         wrt_patterns = info['wrt_patterns']
-        matches_prom = set()
+        if '*' in wrt_patterns:
+            info['wrt_matches_rel'] = None
+            info['wrt_matches'] = None
+            return
+
+        matches_rel = set()
         for w in wrt_patterns:
-            matches_prom.update(find_matches(w, allwrt))
+            matches_rel.update(find_matches(w, allwrt))
 
         # error if nothing matched
-        if not matches_prom:
+        if not matches_rel:
             raise ValueError("{}: Invalid 'wrt' variable(s) specified for colored approx partial "
                              "options: {}.".format(self.msginfo, wrt_patterns))
 
-        info['wrt_matches_prom'] = matches_prom
-        info['wrt_matches'] = [rel_name2abs_name(self, n) for n in matches_prom]
+        info['wrt_matches_rel'] = matches_rel
+        info['wrt_matches'] = [rel_name2abs_name(self, n) for n in matches_rel]
 
     def _update_subjac_sparsity(self, sparsity):
         """
@@ -412,11 +461,13 @@ class Component(System):
                 wrt_abs = '.'.join((pathname, wrt)) if pathname else wrt
                 abs_key = (of_abs, wrt_abs)
                 if abs_key in self._subjacs_info:
+                    meta = self._subjacs_info[abs_key]
                     # add sparsity info to existing partial info
-                    self._subjacs_info[abs_key]['sparsity'] = tup
+                    meta['sparsity'] = tup
 
     def add_input(self, name, val=1.0, shape=None, src_indices=None, flat_src_indices=None,
-                  units=None, desc='', tags=None, shape_by_conn=False, copy_shape=None):
+                  units=None, desc='', tags=None, shape_by_conn=False, copy_shape=None,
+                  distributed=None):
         """
         Add an input variable to the component.
 
@@ -452,6 +503,9 @@ class Component(System):
         copy_shape : str or None
             If a str, that str is the name of a variable. Shape this input to match that of
             the named variable.
+        distributed : bool
+            If True, this variable is a distributed variable, so it can have different sizes/values
+            across MPI processes.
 
         Returns
         -------
@@ -499,8 +553,9 @@ class Component(System):
                 if _is_slicer_op(src_indices):
                     src_slice = src_indices
                     if flat_src_indices is not None:
-                        simple_warning(f"{self.msginfo}: Input '{name}' was added with slice "
-                                       "src_indices, so flat_src_indices is ignored.")
+                        issue_warning(f"Input '{name}' was added with slice "
+                                      "src_indices, so flat_src_indices is ignored.",
+                                      prefix=self.msginfo, category=UnusedOptionWarning)
                 else:
                     src_indices = np.asarray(src_indices, dtype=INT_DTYPE)
 
@@ -515,6 +570,15 @@ class Component(System):
                              "deprecated and will become an error in a future release.  Add "
                              "`src_indices` to a `promotes` or `connect` call instead.")
 
+        # until we get rid of component level distributed option, handle the case where
+        # component distributed has been set to True but variable distributed has been set
+        # to False by the caller.
+        if distributed is not False:
+            if distributed is None:
+                distributed = False
+            # using ._dict below to avoid tons of deprecation warnings
+            distributed = distributed or self.options._dict['distributed']['value']
+
         metadata = {
             'value': val,
             'shape': shape,
@@ -525,12 +589,15 @@ class Component(System):
             'src_slice': src_slice,  # store slice def here, if any.  This is never overwritten
             'units': units,
             'desc': desc,
-            'distributed': self.options['distributed'],
+            'distributed': distributed,
             'tags': make_set(tags),
             'shape_by_conn': shape_by_conn,
             'copy_shape': copy_shape,
         }
 
+        # this will get reset later if comm size is 1
+        self._has_distrib_vars |= metadata['distributed']
+
         if self._static_mode:
             var_rel2meta = self._static_var_rel2meta
             var_rel_names = self._static_var_rel_names
@@ -605,7 +672,7 @@ class Component(System):
 
     def add_output(self, name, val=1.0, shape=None, units=None, res_units=None, desc='',
                    lower=None, upper=None, ref=1.0, ref0=0.0, res_ref=1.0, tags=None,
-                   shape_by_conn=False, copy_shape=None):
+                   shape_by_conn=False, copy_shape=None, distributed=None):
         """
         Add an output variable to the component.
 
@@ -653,6 +720,9 @@ class Component(System):
         copy_shape : str or None
             If a str, that str is the name of a variable. Shape this output to match that of
             the named variable.
+        distributed : bool
+            If True, this variable is a distributed variable, so it can have different sizes/values
+            across MPI processes.
 
         Returns
         -------
@@ -740,6 +810,15 @@ class Component(System):
         else:
             self._has_resid_scaling |= np.any(res_ref != 1.0)
 
+        # until we get rid of component level distributed option, handle the case where
+        # component distributed has been set to True but variable distributed has been set
+        # to False by the caller.
+        if distributed is not False:
+            if distributed is None:
+                distributed = False
+            # using ._dict below to avoid tons of deprecation warnings
+            distributed = distributed or self.options._dict['distributed']['value']
+
         metadata = {
             'value': val,
             'shape': shape,
@@ -747,7 +826,7 @@ class Component(System):
             'units': units,
             'res_units': res_units,
             'desc': desc,
-            'distributed': self.options['distributed'],
+            'distributed': distributed,
             'tags': make_set(tags),
             'ref': format_as_float_or_array('ref', ref, flatten=True),
             'ref0': format_as_float_or_array('ref0', ref0, flatten=True),
@@ -758,6 +837,9 @@ class Component(System):
             'copy_shape': copy_shape
         }
 
+        # this will get reset later if comm size is 1
+        self._has_distrib_vars |= metadata['distributed']
+
         # We may not know the pathname yet, so we have to use name for now, instead of abs_name.
         if self._static_mode:
             var_rel2meta = self._static_var_rel2meta
@@ -859,12 +941,9 @@ class Component(System):
 
         Returns
         -------
-        set
+        list
             Names of inputs where src_indices were added.
         """
-        if not self.options['distributed'] or self.comm.size == 1:
-            return set()
-
         iproc = self.comm.rank
         abs2meta_in = self._var_abs2meta['input']
         all_abs2meta_in = all_abs2meta['input']
@@ -872,13 +951,13 @@ class Component(System):
 
         sizes_in = self._var_sizes['nonlinear']['input']
         sizes_out = all_sizes['nonlinear']['output']
-        added_src_inds = set()
-        for i, iname in enumerate(self._var_allprocs_abs2meta['input']):
-            if iname in abs2meta_in and abs2meta_in[iname]['src_indices'] is None:
-                meta_in = abs2meta_in[iname]
-                src = abs_in2out[iname]
-                out_i = all_abs2idx[src]
-                nzs = np.nonzero(sizes_out[:, out_i])[0]
+        added_src_inds = []
+        # loop over continuous inputs (all procs)
+        for i, (iname, meta_in) in enumerate(abs2meta_in.items()):
+            src = abs_in2out[iname]
+            if meta_in['src_indices'] is None and (
+                    meta_in['distributed'] or all_abs2meta_out[src]['distributed']):
+                nzs = np.nonzero(sizes_out[:, all_abs2idx[src]])[0]
                 if (all_abs2meta_out[src]['global_size'] ==
                         all_abs2meta_in[iname]['global_size'] or nzs.size == self.comm.size):
                     # This offset assumes a 'full' distributed output
@@ -887,7 +966,7 @@ class Component(System):
                 else:  # distributed output (may have some zero size entries)
                     if nzs.size == 1:
                         offset = 0
-                        end = sizes_out[nzs[0], out_i]
+                        end = sizes_out[nzs[0], all_abs2idx[src]]
                     else:
                         # total sizes differ and output is distributed, so can't determine mapping
                         raise RuntimeError(f"{self.msginfo}: Can't determine src_indices "
@@ -899,12 +978,12 @@ class Component(System):
                     inds = inds.reshape(meta_in['shape'])
                 meta_in['src_indices'] = inds
                 meta_in['flat_src_indices'] = True
-                all_abs2meta_in[iname]['has_src_indices'] = True
-                added_src_inds.add(iname)
+                added_src_inds.append(iname)
 
-                simple_warning(f"{self.msginfo}: Component is distributed but input '{iname}' was "
-                               "added without src_indices. Setting src_indices to "
-                               f"np.arange({offset}, {end}, dtype=int).reshape({inds.shape}).")
+                issue_warning(f"Component is distributed but input '{iname}' was "
+                              "added without src_indices. Setting src_indices to "
+                              f"np.arange({offset}, {end}, dtype=int).reshape({inds.shape}).",
+                              prefix=self.msginfo, category=DistributedComponentWarning)
 
         return added_src_inds
 
@@ -1020,10 +1099,10 @@ class Component(System):
         if dependent:
             meta['value'] = val
             if rows is not None:
-                meta['rows'] = rows
-                meta['cols'] = cols
+                rows = np.array(rows, dtype=INT_DTYPE, copy=False)
+                cols = np.array(cols, dtype=INT_DTYPE, copy=False)
 
-                # First, check the length of rows and cols to catch this easy mistake and give a
+                # Check the length of rows and cols to catch this easy mistake and give a
                 # clear message.
                 if len(cols) != len(rows):
                     raise RuntimeError("{}: d({})/d({}): declare_partials has been called "
@@ -1031,14 +1110,33 @@ class Component(System):
                                        " but rows is length {} while cols is length "
                                        "{}.".format(self.msginfo, of, wrt, len(rows), len(cols)))
 
+                if rows.size > 0 and rows.min() < 0:
+                    msg = '{}: d({})/d({}): row indices must be non-negative'
+                    raise ValueError(msg.format(self.msginfo, of, wrt))
+                if cols.size > 0 and cols.min() < 0:
+                    msg = '{}: d({})/d({}): col indices must be non-negative'
+                    raise ValueError(msg.format(self.msginfo, of, wrt))
+
+                meta['rows'] = rows
+                meta['cols'] = cols
+
                 # Check for repeated rows/cols indices.
-                idxset = set(zip(rows, cols))
-                if len(rows) - len(idxset) > 0:
-                    dups = [n for n, val in Counter(zip(rows, cols)).items() if val > 1]
-                    raise RuntimeError("{}: d({})/d({}): declare_partials has been called "
-                                       "with rows and cols that specify the following duplicate "
-                                       "subjacobian entries: {}.".format(self.msginfo, of, wrt,
-                                                                         sorted(dups)))
+                size = len(rows)
+                if size > 0:
+                    coo = coo_matrix((np.ones(size, dtype=np.short), (rows, cols)))
+                    dsize = coo.data.size
+                    csc = coo.tocsc()
+                    # csc adds values at duplicate indices together, so result will be that data
+                    # size is less if there are duplicates
+                    if csc.data.size < dsize:
+                        coo = csc.tocoo()
+                        del csc
+                        inds = np.where(coo.data > 1.)
+                        dups = list(zip(coo.row[inds], coo.col[inds]))
+                        raise RuntimeError("{}: d({})/d({}): declare_partials has been called "
+                                           "with rows and cols that specify the following duplicate"
+                                           " subjacobian entries: {}.".format(self.msginfo, of, wrt,
+                                                                              sorted(dups)))
 
         if method_func is not None:
             # we're doing approximations
@@ -1047,11 +1145,6 @@ class Component(System):
             self._get_approx_scheme(method)
 
             default_opts = method_func.DEFAULT_OPTIONS
-
-            # If rows/cols is specified
-            if rows is not None or cols is not None:
-                raise ValueError("{}: d({})/d({}): Sparse FD specification not supported "
-                                 "yet.".format(self.msginfo, of, wrt))
         else:
             default_opts = ()
 
@@ -1196,7 +1289,7 @@ class Component(System):
 
         Returns
         -------
-        dict(wrt : (options))
+        dict(wrt: (options))
             Dictionary keyed by name with tuples of options (method, form, step, step_calc)
         """
         opts = {}
@@ -1248,7 +1341,7 @@ class Component(System):
 
         return opts
 
-    def _declare_partials(self, of, wrt, dct, quick_declare=False):
+    def _declare_partials(self, of, wrt, dct):
         """
         Store subjacobian metadata for later use.
 
@@ -1263,20 +1356,7 @@ class Component(System):
             May also contain glob patterns.
         dct : dict
             Metadata dict specifying shape, and/or approx properties.
-        quick_declare : bool
-            This is set to True when declaring the jacobian diagonal terms for explicit
-            components. The checks and conversions are all skipped to improve performance for
-            cases with large numbers of explicit components or indepvarcomps.
         """
-        if quick_declare:
-            self._subjacs_info[rel_key2abs_key(self, (of, wrt))] = {
-                'rows': np.array(dct['rows'], dtype=INT_DTYPE, copy=False),
-                'cols': np.array(dct['cols'], dtype=INT_DTYPE, copy=False),
-                'shape': (len(dct['rows']), len(dct['cols'])),
-                'value': dct['value'],
-            }
-            return
-
         val = dct['value'] if 'value' in dct else None
         is_scalar = isscalar(val)
         dependent = dct['dependent']
@@ -1286,14 +1366,6 @@ class Component(System):
                 rows = dct['rows']
                 cols = dct['cols']
 
-                rows = np.array(rows, dtype=INT_DTYPE, copy=False)
-                cols = np.array(cols, dtype=INT_DTYPE, copy=False)
-
-                if rows.shape != cols.shape:
-                    raise ValueError('{}: d({})/d({}): rows and cols must have the same shape,'
-                                     ' rows: {}, cols: {}'.format(self.msginfo, of, wrt,
-                                                                  rows.shape, cols.shape))
-
                 if is_scalar:
                     val = np.full(rows.size, val, dtype=float)
                     is_scalar = False
@@ -1313,12 +1385,6 @@ class Component(System):
                     val = np.zeros_like(rows, dtype=float)
 
                 if rows.size > 0:
-                    if rows.min() < 0:
-                        msg = '{}: d({})/d({}): row indices must be non-negative'
-                        raise ValueError(msg.format(self.msginfo, of, wrt))
-                    if cols.min() < 0:
-                        msg = '{}: d({})/d({}): col indices must be non-negative'
-                        raise ValueError(msg.format(self.msginfo, of, wrt))
                     rows_max = rows.max()
                     cols_max = cols.max()
                 else:
@@ -1371,12 +1437,12 @@ class Component(System):
                 if shape[0] == 0 or shape[1] == 0:
                     msg = "{}: '{}' is an array of size 0"
                     if shape[0] == 0:
-                        if not abs2meta_out[of]['distributed']:
-                            # non-distributed components are not allowed to have zero size inputs
-                            raise ValueError(msg.format(self.msginfo, of))
-                        else:
+                        if abs2meta_out[of]['distributed']:
                             # distributed comp are allowed to have zero size inputs on some procs
                             rows_max = -1
+                        else:
+                            # non-distributed components are not allowed to have zero size inputs
+                            raise ValueError(msg.format(self.msginfo, of))
                     if shape[1] == 0:
                         if wrt in abs2meta_in:
                             distrib = abs2meta_in[wrt]['distributed']
@@ -1413,16 +1479,16 @@ class Component(System):
 
                 self._subjacs_info[abs_key] = meta
 
-    def _find_partial_matches(self, of, wrt):
+    def _find_partial_matches(self, of_pattern, wrt_pattern):
         """
         Find all partial derivative matches from of and wrt.
 
         Parameters
         ----------
-        of : str or list of str
+        of_pattern : str or list of str
             The relative name of the residual(s) that derivatives are being computed for.
             May also contain a glob pattern.
-        wrt : str or list of str
+        wrt_pattern : str or list of str
             The relative name of the variables that derivatives are taken with respect to.
             This can contain the name of any input or output variable.
             May also contain a glob pattern.
@@ -1434,12 +1500,12 @@ class Component(System):
             where of_matches is a list of tuples (pattern, matches) and wrt_matches is a list of
             tuples (pattern, output_matches, input_matches).
         """
-        of_list = [of] if isinstance(of, str) else of
-        wrt_list = [wrt] if isinstance(wrt, str) else wrt
-        of, wrt = self._get_partials_varlists()
+        of_list = [of_pattern] if isinstance(of_pattern, str) else of_pattern
+        wrt_list = [wrt_pattern] if isinstance(wrt_pattern, str) else wrt_pattern
+        ofs, wrts = self._get_partials_varlists()
 
-        of_pattern_matches = [(pattern, find_matches(pattern, of)) for pattern in of_list]
-        wrt_pattern_matches = [(pattern, find_matches(pattern, wrt)) for pattern in wrt_list]
+        of_pattern_matches = [(pattern, find_matches(pattern, ofs)) for pattern in of_list]
+        wrt_pattern_matches = [(pattern, find_matches(pattern, wrts)) for pattern in wrt_list]
         return of_pattern_matches, wrt_pattern_matches
 
     def _check_partials_meta(self, abs_key, val, shape):
@@ -1478,9 +1544,16 @@ class Component(System):
         """
         self._get_static_wrt_matches()
         subjacs = self._subjacs_info
-        for key in self._approx_subjac_keys_iter():
-            meta = subjacs[key]
-            self._approx_schemes[meta['method']].add_approximation(key, self, meta)
+        wrtset = set()
+        subjac_keys = self._get_approx_subjac_keys()
+        # go through subjac keys in reverse and only add approx for the last of each wrt
+        # (this prevents warnings that could confuse users)
+        for i in range(len(subjac_keys) - 1, -1, -1):
+            key = subjac_keys[i]
+            if key[1] not in wrtset:
+                wrtset.add(key[1])
+                meta = subjacs[key]
+                self._approx_schemes[meta['method']].add_approximation(key, self, meta)
 
     def _guess_nonlinear(self):
         """
@@ -1507,6 +1580,7 @@ class Component(System):
                     if not self._coloring_info['dynamic']:
                         coloring._check_config_partial(self)
                     self._update_subjac_sparsity(coloring.get_subjac_sparsity())
+                self._jacobian._restore_approx_sparsity()
 
     def _resolve_src_inds(self, my_tdict, top):
         abs2meta_in = self._var_abs2meta['input']
@@ -1531,7 +1605,14 @@ class Component(System):
                                                 meta['src_indices'], src_shape)
                 elif _is_slicer_op(src_inds):
                     meta['src_slice'] = src_inds
-                    src_inds = _slice_indices(src_inds, np.prod(parent_src_shape), parent_src_shape)
+                    try:
+                        src_inds = _slice_indices(src_inds, np.prod(parent_src_shape),
+                                                  parent_src_shape)
+                    except IndexError as err:
+                        raise IndexError(f"{self.msginfo}:\nError '{err}'\n  in "
+                                         f"resolving source indices in connection "
+                                         f"between source='{oldprom}' "
+                                         f"and target='{tgt}'\n  with src_indices='{src_inds}'")
                     meta['flat_src_indices'] = True
                 elif src_inds.ndim == 1:
                     meta['flat_src_indices'] = True
@@ -1562,7 +1643,3 @@ class _DictValues(object):
 
     def items(self):
         return [(key, self._dict[key]['value']) for key in self._dict]
-
-    def iteritems(self):
-        for key, val in self._dict.iteritems():
-            yield key, val['value']
