@@ -12,28 +12,24 @@ import time
 import numpy as np
 
 from openmdao.core.constants import INT_DTYPE
-from openmdao.utils.general_utils import ContainsAll, simple_warning, _prom2ivc_src_dict
+from openmdao.utils.general_utils import ContainsAll, _prom2ivc_src_dict
 
-from openmdao.utils.mpi import MPI, multi_proc_exception_check
+from openmdao.utils.mpi import MPI, check_mpi_env, multi_proc_exception_check
 from openmdao.utils.coloring import _initialize_model_approx, Coloring
+from openmdao.warnings import issue_warning, DerivativesWarning
+from openmdao.vectors.vector import _full_slice
 
-# Attempt to import petsc4py.
-# If OPENMDAO_REQUIRE_MPI is set to a recognized positive value, attempt import
-# and raise exception on failure. If set to anything else, no import is attempted.
-if 'OPENMDAO_REQUIRE_MPI' in os.environ:
-    if os.environ['OPENMDAO_REQUIRE_MPI'].lower() in ['always', '1', 'true', 'yes']:
-        from petsc4py import PETSc
-    else:
-        PETSc = None
-# If OPENMDAO_REQUIRE_MPI is unset, attempt to import petsc4py, but continue on failure
-# with a notification.
-else:
+
+use_mpi = check_mpi_env()
+if use_mpi is not False:
     try:
         from petsc4py import PETSc
     except ImportError:
         PETSc = None
-        sys.stdout.write("Unable to import petsc4py. Parallel processing unavailable.\n")
-        sys.stdout.flush()
+        if use_mpi is True:
+            raise ImportError("Importing petsc4py failed and OPENMDAO_USE_MPI is true.")
+elif use_mpi is False:
+    PETSc = None
 
 _contains_all = ContainsAll()
 
@@ -77,7 +73,7 @@ class _TotalJacInfo(object):
     output_list : list of str
         List of names of output variables for this total jacobian.  In fwd mode, outputs
         are responses.  In rev mode, outputs are design variables.
-    output_vec : Dict of vectors keyed by vec_name.
+    output_vec : dict of vectors keyed by vec_name.
         Designated output vectors based on value of fwd.
     owning_ranks : dict
         Map of absolute var name to the MPI process that owns it.
@@ -121,6 +117,8 @@ class _TotalJacInfo(object):
         driver_scaling : bool
             If True (default), scale derivative values by the quantities specified when the desvars
             and responses were added. If False, leave them unscaled.
+        get_remote : bool
+            Whether to get remote variables if using MPI.
         """
         driver = problem.driver
         prom2abs = problem.model._var_allprocs_prom2abs_list['output']
@@ -255,7 +253,7 @@ class _TotalJacInfo(object):
                            "be turned off.\ncoloring design vars: %s, current design vars: "
                            "%s\ncoloring responses: %s, current responses: %s." %
                            (driver_wrt, wrt, driver_of, of))
-                    simple_warning(msg)
+                    issue_warning(msg, category=DerivativesWarning)
                     self.simul_coloring = None
 
             if not isinstance(self.simul_coloring, Coloring):
@@ -804,7 +802,7 @@ class _TotalJacInfo(object):
                 if name in abs2idx and name in slices and name not in self.remote_vois:
                     var_idx = abs2idx[name]
                     slc = slices[name]
-                    if MPI and meta['distributed'] and model.comm.size > 1 and self.get_remote:
+                    if MPI and meta['distributed'] and self.get_remote:
                         if indices is not None:
                             local_idx, sizes_idx, _ = self._dist_driver_vars[name]
 
@@ -1621,12 +1619,14 @@ class _TotalJacInfo(object):
                         # constraint wrt all other inputs.
                         continue
 
-                    ofidx = of_idx[output_name] if output_name in of_idx else None
-                    wrtidx = wrt_idx[input_name] if input_name in wrt_idx else None
+                    ofidx = of_idx[output_name] if output_name in of_idx else _full_slice
+                    wrtidx = wrt_idx[input_name] if input_name in wrt_idx else _full_slice
 
-                    totals[prom_out, prom_in][:] = _get_subjac(approx_jac[output_name, input_name],
-                                                               prom_out, prom_in, ofidx, wrtidx,
-                                                               dist_resp, comm)
+                    approxJ = approx_jac[output_name, input_name]
+
+                    totals[prom_out, prom_in][:] = _get_approx_subjac(approxJ,
+                                                                      prom_out, prom_in, ofidx,
+                                                                      wrtidx, dist_resp, comm)
 
         elif return_format in ('dict', 'array'):
             for prom_out, output_name in zip(self.prom_of, of):
@@ -1645,18 +1645,18 @@ class _TotalJacInfo(object):
                         # constraint wrt all other inputs.
                         continue
 
-                    ofidx = of_idx[output_name] if output_name in of_idx else None
-                    wrtidx = wrt_idx[input_name] if input_name in wrt_idx else None
+                    ofidx = of_idx[output_name] if output_name in of_idx else _full_slice
+                    wrtidx = wrt_idx[input_name] if input_name in wrt_idx else _full_slice
 
                     if prom_out == prom_in and isinstance(tot[prom_in], dict):
                         rows, cols, data = tot[prom_in]['coo']
-                        data[:] = _get_subjac(approx_jac[output_name, input_name],
-                                              prom_out, prom_in, ofidx, wrtidx,
-                                              dist_resp, comm)[rows, cols]
+                        data[:] = _get_approx_subjac(approx_jac[output_name, input_name],
+                                                     prom_out, prom_in, ofidx, wrtidx,
+                                                     dist_resp, comm)[rows, cols]
                     else:
-                        tot[prom_in][:] = _get_subjac(approx_jac[output_name, input_name],
-                                                      prom_out, prom_in, ofidx, wrtidx,
-                                                      dist_resp, comm)
+                        tot[prom_in][:] = _get_approx_subjac(approx_jac[output_name, input_name],
+                                                             prom_out, prom_in, ofidx, wrtidx,
+                                                             dist_resp, comm)
 
         else:
             msg = "Unsupported return format '%s." % return_format
@@ -1678,6 +1678,41 @@ class _TotalJacInfo(object):
 
         return totals
 
+    def _get_zero_inds(self, name, tup, jac_arr):
+        """
+        Get zero indices relative to the named variable for jac row/col 'jac_arr'.
+
+        Parameters
+        ----------
+        name : str
+            Name of the design var or response.
+        tup : tuple
+            Contains jacobian slice and dv/response indices, if any.
+        jac_arr : ndarray
+            Row or column of jacobian being checked for zero entries.
+
+        Returns
+        -------
+        ndarray
+            Index array of zero entries.
+        """
+        inds = tup[1]  # these must be indices into the flattened var
+        shname = 'shape' if self.get_remote else 'global_shape'
+        shape = self.model._var_allprocs_abs2meta['output'][name][shname]
+        vslice = jac_arr[tup[0]]
+
+        if inds is None:
+            zero_idxs = np.nonzero(vslice.reshape(shape))
+        else:
+            zero_idxs = np.nonzero(vslice)
+            if zero_idxs[0].size == 0:
+                return zero_idxs
+            varr = np.zeros(shape, dtype=bool)
+            varr.flat[inds[zero_idxs]] = True
+            zero_idxs = np.nonzero(varr)
+
+        return zero_idxs
+
     def check_total_jac(self, raise_error=True, tol=1e-16):
         """
         Check recently computed totals derivative jacobian for problems.
@@ -1693,49 +1728,57 @@ class _TotalJacInfo(object):
         raise_error : bool
             If True, raise an exception if a zero row or column is found.
         """
-        J = np.abs(self.J)
-        nrows, ncols = J.shape
-        zero_rows = []
-        zero_cols = []
+        nzrows, nzcols = np.nonzero(np.abs(self.J) > tol)
 
         # Check for zero rows, which correspond to constraints unaffected by any design vars.
-        for j in np.arange(nrows):
-            if np.all(J[j, :] < tol):
-                for name, val in self.of_meta.items():
-                    if j > val[0].stop - 1:
-                        continue
-                    break
-                if name in self.ivc_print_names:
-                    name = self.ivc_print_names[name]
-                if name not in zero_rows:
-                    zero_rows.append(name)
+        col = np.ones(self.J.shape[0], dtype=bool)
+        col[nzrows] = False  # False in this case means nonzero
+        if np.any(col):  # there's at least 1 row that's zero across all columns
+            zero_rows = []
+            for name, tup in self.of_meta.items():
+                zero_idxs = self._get_zero_inds(name, tup, col)
 
-        if zero_rows:
-            msg = f"Constraints or objectives {zero_rows} cannot be impacted by the design " + \
-                "variables of the problem."
-            if raise_error:
-                raise RuntimeError(msg)
-            else:
-                simple_warning(msg)
+                if zero_idxs[0].size > 0:
+                    if len(zero_idxs) == 1:
+                        zero_rows.append((self.ivc_print_names.get(name, name),
+                                          list(zero_idxs[0])))
+                    else:
+                        zero_rows.append((self.ivc_print_names.get(name, name),
+                                          list(zip(*zero_idxs))))
+
+            if zero_rows:
+                zero_rows = [f"('{n}', inds={idxs})" for n, idxs in zero_rows]
+                msg = (f"Constraints or objectives [{', '.join(zero_rows)}] cannot be impacted by "
+                       "the design variables of the problem.")
+                if raise_error:
+                    raise RuntimeError(msg)
+                else:
+                    issue_warning(msg, category=DerivativesWarning)
 
         # Check for zero cols, which correspond to design vars that don't affect anything.
-        for j in np.arange(ncols):
-            if np.all(J[:, j] < tol):
-                for name, val in self.wrt_meta.items():
-                    if j > val[0].stop - 1:
-                        continue
-                    break
-                if name in self.ivc_print_names:
-                    name = self.ivc_print_names[name]
-                if name not in zero_cols:
-                    zero_cols.append(name)
+        row = np.ones(self.J.shape[1], dtype=bool)
+        row[nzcols] = False  # False in this case means nonzero
+        if np.any(row):  # there's at least 1 col that's zero across all rows
+            zero_cols = []
+            for name, tup in self.wrt_meta.items():
+                zero_idxs = self._get_zero_inds(name, tup, row)
 
-        if zero_cols:
-            msg = f"Design variables {zero_cols} have no impact on the constraints or objective."
-            if raise_error:
-                raise RuntimeError(msg)
-            else:
-                simple_warning(msg)
+                if zero_idxs[0].size > 0:
+                    if len(zero_idxs) == 1:
+                        zero_cols.append((self.ivc_print_names.get(name, name),
+                                          list(zero_idxs[0])))
+                    else:
+                        zero_cols.append((self.ivc_print_names.get(name, name),
+                                          list(zip(*zero_idxs))))
+
+            if zero_cols:
+                zero_cols = [f"('{n}', inds={idxs})" for n, idxs in zero_cols]
+                msg = (f"Design variables [{', '.join(zero_cols)}] have no impact on the "
+                       "constraints or objective.")
+                if raise_error:
+                    raise RuntimeError(msg)
+                else:
+                    issue_warning(msg, category=DerivativesWarning)
 
     def _restore_linear_solution(self, vec_names, key, mode):
         """
@@ -1873,7 +1916,7 @@ class _TotalJacInfo(object):
             self.model._recording_iter.pop()
 
 
-def _get_subjac(jac_meta, prom_out, prom_in, of_idx, wrt_idx, dist_resp, comm):
+def _get_approx_subjac(jac_meta, prom_out, prom_in, of_idx, wrt_idx, dist_resp, comm):
     """
     Return proper subjacobian based on input/output names and indices.
 
@@ -1885,9 +1928,9 @@ def _get_subjac(jac_meta, prom_out, prom_in, of_idx, wrt_idx, dist_resp, comm):
         Promoted output name.
     prom_in : str
         Promoted input name.
-    of_idx : ndarray or None
+    of_idx : ndarray or slice
         Output indices, if any.
-    wrt_idx : ndarray or None
+    wrt_idx : ndarray or slice
         Input indices, if any.
     dist_resp : None or tuple
         Tuple containing indices and sizes if this response is distributed.
@@ -1899,13 +1942,23 @@ def _get_subjac(jac_meta, prom_out, prom_in, of_idx, wrt_idx, dist_resp, comm):
     ndarray
         The desired subjacobian.
     """
-    if jac_meta['rows'] is not None:  # sparse list format
-        # This is a design variable that was declared as an obj/con.
-        tot = np.eye(len(jac_meta['value']))
-        if of_idx is not None:
-            tot = tot[of_idx, :]
-        if wrt_idx is not None:
-            tot = tot[:, wrt_idx]
+    # of_idx and wrt_idx are relative to the full sized of and wrt vars, but
+    # 'rows' and 'cols' are relative to the subjac after compression based on of_idx
+    # and wrt_idx.
+    if jac_meta['rows'] is not None:
+        if prom_in == prom_out:
+            nrows, ncols = jac_meta['shape']
+            if of_idx is _full_slice or wrt_idx is _full_slice:
+                sz = nrows  # nrows = ncols since this subjac is square
+            else:
+                sz = np.max(of_idx)
+                sz = max(sz, np.max(wrt_idx)) + 1
+            # take sections of the identity matrix based on of_idx and wrt_idx
+            sz = max(sz, nrows, ncols)
+            tot = np.eye(sz)[of_idx, wrt_idx]
+        else:
+            tot = np.zeros(jac_meta['shape'])
+            tot[jac_meta['rows'], jac_meta['cols']] = jac_meta['value']
     else:
         tot = jac_meta['value']
 
