@@ -15,8 +15,9 @@ from openmdao.test_suite.components.paraboloid_distributed import DistParab
 from openmdao.test_suite.components.sellar import SellarDerivativesGrouped
 from openmdao.utils.assert_utils import assert_near_equal, assert_warning
 from openmdao.utils.general_utils import set_pyoptsparse_opt, run_driver
-from openmdao.utils.testing_utils import use_tempdirs
+from openmdao.utils.testing_utils import use_tempdirs, require_pyoptsparse
 from openmdao.utils.mpi import MPI
+from openmdao.warnings import OMDeprecationWarning
 
 # check that pyoptsparse is installed
 # if it is, try to use SNOPT but fall back to SLSQP
@@ -160,11 +161,11 @@ class TestNotInstalled(unittest.TestCase):
                          'pyOptSparseDriver is not available, pyOptsparse is not installed.')
 
 
-@unittest.skipIf(OPT is None or OPTIMIZER is None, "only run if pyoptsparse is installed.")
 @unittest.skipUnless(MPI, "MPI is required.")
 class TestMPIScatter(unittest.TestCase):
     N_PROCS = 2
 
+    @require_pyoptsparse(OPTIMIZER)
     def test_design_vars_on_all_procs_pyopt(self):
 
         prob = om.Problem()
@@ -190,6 +191,7 @@ class TestMPIScatter(unittest.TestCase):
         proc_vals = MPI.COMM_WORLD.allgather([prob['x'], prob['y'], prob['c'], prob['f_xy']])
         np.testing.assert_array_almost_equal(proc_vals[0], proc_vals[1])
 
+    @require_pyoptsparse(OPTIMIZER)
     def test_opt_distcomp(self):
         size = 7
 
@@ -206,7 +208,8 @@ class TestMPIScatter(unittest.TestCase):
         model.add_subsystem('sum', om.ExecComp('f_sum = sum(f_xy)',
                                                f_sum=np.ones((size, )),
                                                f_xy=np.ones((size, ))),
-                            promotes=['*'])
+                            promotes_outputs=['*'])
+        model.promotes('sum', inputs=['f_xy'], src_indices=om.slicer[:])
 
         model.add_design_var('x', lower=-50.0, upper=50.0)
         model.add_design_var('y', lower=-50.0, upper=50.0)
@@ -228,10 +231,8 @@ class TestMPIScatter(unittest.TestCase):
                           np.zeros(7),
                           1e-5)
 
+    @require_pyoptsparse('ParOpt')
     def test_paropt_distcomp(self):
-        _, local_opt = set_pyoptsparse_opt('ParOpt')
-        if local_opt != 'ParOpt':
-            raise unittest.SkipTest("pyoptsparse is not providing ParOpt")
         size = 7
 
         prob = om.Problem()
@@ -270,7 +271,7 @@ class TestMPIScatter(unittest.TestCase):
                           1e-5)
 
 
-@unittest.skipIf(OPT is None or OPTIMIZER is None, "only run if pyoptsparse is installed.")
+@require_pyoptsparse(OPTIMIZER)
 @use_tempdirs
 class TestPyoptSparse(unittest.TestCase):
 
@@ -2024,10 +2025,8 @@ class TestPyoptSparse(unittest.TestCase):
 
         assert_near_equal(prob['z'][0], 1.9776, 1e-3)
 
+    @require_pyoptsparse('ParOpt')
     def test_ParOpt_basic(self):
-        _, local_opt = set_pyoptsparse_opt('ParOpt')
-        if local_opt != 'ParOpt':
-            raise unittest.SkipTest("pyoptsparse is not providing ParOpt")
 
         prob = om.Problem()
         model = prob.model = SellarDerivativesGrouped()
@@ -2141,7 +2140,7 @@ class TestPyoptSparse(unittest.TestCase):
             prob.run_driver()
 
         self.assertEqual(str(msg.exception),
-                         "Constraints or objectives ['parab.z'] cannot be impacted by the design " + \
+                         "Constraints or objectives [('parab.z', inds=[0])] cannot be impacted by the design " + \
                          "variables of the problem.")
 
     def test_singular_jac_error_desvars(self):
@@ -2176,7 +2175,7 @@ class TestPyoptSparse(unittest.TestCase):
             prob.run_driver()
 
         self.assertEqual(str(msg.exception),
-                         "Design variables ['z'] have no impact on the constraints or objective.")
+                         "Design variables [('z', inds=[0])] have no impact on the constraints or objective.")
 
     def test_singular_jac_ignore(self):
         prob = om.Problem()
@@ -2235,7 +2234,7 @@ class TestPyoptSparse(unittest.TestCase):
 
         prob.setup()
 
-        msg = "Constraints or objectives ['parab.z'] cannot be impacted by the design variables of the problem."
+        msg = "Constraints or objectives [('parab.z', inds=[0])] cannot be impacted by the design variables of the problem."
 
         with assert_warning(UserWarning, msg):
             prob.run_driver()
@@ -2677,7 +2676,7 @@ class TestPyoptSparseSnoptFeature(unittest.TestCase):
         prob.driver.options['optimizer'] = "SNOPT"
 
         msg = "The option 'user_teriminate_signal' was misspelled and will be deprecated. Please use 'user_terminate_signal' instead."
-        with assert_warning(DeprecationWarning, msg):
+        with assert_warning(OMDeprecationWarning, msg):
             prob.driver.options['user_teriminate_signal'] = None
 
 
@@ -2708,9 +2707,9 @@ class MatMultCompExact(om.ExplicitComponent):
 
         Parameters
         ----------
-        inputs : Vector
+        inputs: Vector
             unscaled, dimensional input variables read via inputs[key]
-        partials : Jacobian
+        partials: Jacobian
             sub-jac components written to partials[output_name, input_name]
         """
         if self.sparse:
