@@ -4,7 +4,7 @@ CaseReader factory function.
 from openmdao.recorders.sqlite_reader import SqliteCaseReader
 
 
-def CaseReader(filename, pre_load=True):
+def CaseReader(filename, pre_load=True, metadata_filename=None):
     """
     Return a CaseReader for the given file.
 
@@ -15,10 +15,12 @@ def CaseReader(filename, pre_load=True):
         Currently only sqlite database files recorded via SqliteRecorder are supported.
     pre_load : bool
         If True, load all the data into memory during initialization.
+    metadata_filename : str
+        For separate metadata from parallel runs, the metadata database filename.
 
     Returns
     -------
     reader : BaseCaseReader
         An instance of a CaseReader.
     """
-    return SqliteCaseReader(filename, pre_load)
+    return SqliteCaseReader(filename, pre_load, metadata_filename)
