@@ -232,7 +232,7 @@ class DirectSolver(LinearSolver):
         x_data = xvec.asarray(copy=True)
 
         nmtx = x_data.size
-        eye = np.eye(nmtx)
+        seed = np.zeros(x_data.size)
         mtx = np.empty((nmtx, nmtx), dtype=b_data.dtype)
         scope_out, scope_in = system._get_scope()
         vnames = ['linear']
@@ -240,7 +240,9 @@ class DirectSolver(LinearSolver):
         # Assemble the Jacobian by running the identity matrix through apply_linear
         for i in range(nmtx):
             # set value of x vector to provided value
-            xvec.set_val(eye[:, i])
+            seed[i - 1] = 0.
+            seed[i] = 1.
+            xvec.set_val(seed)
 
             # apply linear
             system._apply_linear(self._assembled_jac, vnames, self._rel_systems, 'fwd',
