@@ -50,14 +50,14 @@ class TestScipyKrylov(LinearSolverTests.LinearSolverTestCase):
         d_residuals.set_val(1.0)
         d_outputs.set_val(0.0)
         group.run_solve_linear(['linear'], 'fwd')
-        output = d_outputs._data
+        output = d_outputs.asarray()
         assert_near_equal(output, group.expected_solution, 1e-15)
 
         # reverse
         d_outputs.set_val(1.0)
         d_residuals.set_val(0.0)
         group.run_solve_linear(['linear'], 'rev')
-        output = d_residuals._data
+        output = d_residuals.asarray()
         assert_near_equal(output, group.expected_solution, 1e-15)
 
     def test_solve_linear_scipy_maxiter(self):
@@ -115,7 +115,7 @@ class TestScipyKrylov(LinearSolverTests.LinearSolverTestCase):
         d_outputs.set_val(0.0)
         g1.run_solve_linear(['linear'], 'fwd')
 
-        output = d_outputs._data
+        output = d_outputs.asarray()
         assert_near_equal(output, g1.expected_solution, 1e-15)
 
         # reverse
@@ -126,7 +126,7 @@ class TestScipyKrylov(LinearSolverTests.LinearSolverTestCase):
         g1.linear_solver._linearize()
         g1.run_solve_linear(['linear'], 'rev')
 
-        output = d_residuals._data
+        output = d_residuals.asarray()
         assert_near_equal(output, g1.expected_solution, 3e-15)
 
     def test_linear_solution_cache(self):
