@@ -266,22 +266,6 @@ class NewtonSolver(NonlinearSolver):
             if self.linear_solver._assembled_jac is not None:
                 self.linear_solver._assembled_jac.set_complex_step_mode(active)
 
-    def _mpi_print_header(self):
-        """
-        Print header text before solving.
-        """
-        if (self.options['iprint'] > 0 and self._system().comm.rank == 0):
-
-            pathname = self._system().pathname
-            if pathname:
-                nchar = len(pathname)
-                prefix = self._solver_info.prefix
-                header = prefix + "\n"
-                header += prefix + nchar * "=" + "\n"
-                header += prefix + pathname + "\n"
-                header += prefix + nchar * "="
-                print(header)
-
     def cleanup(self):
         """
         Clean up resources prior to exit.
