@@ -2,11 +2,13 @@
 
 import unittest
 
+import numpy as np
+
 import openmdao.api as om
 
-from openmdao.utils.assert_utils import assert_near_equal
+from openmdao.utils.assert_utils import assert_near_equal, assert_warning, assert_no_warning
 from openmdao.test_suite.components.sellar import SellarDerivatives
-from openmdao.test_suite.components.double_sellar import DoubleSellar
+from openmdao.test_suite.components.double_sellar import DoubleSellar, SubSellar
 
 
 class TestSolverFeatures(unittest.TestCase):
@@ -86,6 +88,71 @@ class TestSolverFeatures(unittest.TestCase):
         msg = "Solver 'NL: Newton' on system '' stalled after 4 iterations."
         self.assertEqual(str(context.exception), msg)
 
+    def test_nonlinear_solver_bounds_stall_warning(self):
+        prob = om.Problem()
+
+        prob.model.add_subsystem('comp', om.ExecComp('y=3*x+1'), promotes=['*'])
+
+        balance = prob.model.add_subsystem('balance', om.BalanceComp(), promotes=['*'])
+        balance.add_balance('x', lower=-.1, upper=10, rhs_val=0, lhs_name='y')
+
+        newton = prob.model.nonlinear_solver = om.NewtonSolver()
+        newton.options['solve_subsystems'] = True
+        newton.options['stall_limit'] = 5
+        newton.options['stall_tol'] = 1e-8
+        newton.options['maxiter'] = 100
+        newton.options['err_on_non_converge'] = False
+
+        prob.model.linear_solver = om.DirectSolver()
+
+        prob.setup()
+
+        msg = (f"Your model has stalled three times and may be violating the bounds. "
+                f"In the future, turn on print_bound_enforce in your solver options "
+                f"here: \nnonlinear_solver.linesearch.options"
+                f"['print_bound_enforce']=True. "
+                f"\nThe bound(s) being violated now are:\n")
+        with assert_warning(UserWarning, msg):
+            prob.run_model()
+
+        newton.linesearch.options['print_bound_enforce'] = True
+
+        prob.setup()
+
+        with assert_no_warning(UserWarning, msg):
+            prob.run_model()
+
+    def test_nonlinear_solver_lower_level_bounds_stall_warning(self):
+
+        prob = om.Problem()
+
+        group1 = prob.model.add_subsystem('balance_group', subsys=om.Group())
+
+        group1.add_subsystem('comp', om.ExecComp('y=3*x+1'), promotes=['*'])
+
+        balance = group1.add_subsystem('balance', om.BalanceComp(), promotes=['*'])
+        balance.add_balance('x', lower=-.1, upper=10, rhs_val=0, lhs_name='y')
+
+        newton = group1.nonlinear_solver = om.NewtonSolver()
+        newton.options['solve_subsystems'] = True
+        newton.options['stall_limit'] = 5
+        newton.options['stall_tol'] = 1e-8
+        newton.options['maxiter'] = 100
+        newton.options['err_on_non_converge'] = False
+
+        group1.linear_solver = om.DirectSolver()
+
+        prob.setup()
+
+        msg = (f"Your model has stalled three times and may be violating the bounds. "
+                f"In the future, turn on print_bound_enforce in your solver options "
+                f"here: \nbalance_group.nonlinear_solver.linesearch.options"
+                f"['print_bound_enforce']=True. "
+                f"\nThe bound(s) being violated now are:\n")
+
+        with assert_warning(UserWarning, msg):
+            prob.run_model()
+
     def test_feature_stall_detection_newton(self):
         import openmdao.api as om
 
