@@ -50,7 +50,7 @@ class WeightedInterpolator(NNBase):
         ----------
         prediction_points : ndarray
             Points at which interpolation is done.
-        num_neighbors :  int
+        num_neighbors : int
             Number of neighbors to use.
         dist_eff : float
             Exponent used for the distance weighting. Using dist_eff=0 will default to
@@ -62,10 +62,9 @@ class WeightedInterpolator(NNBase):
             Interpolated values at the prediction points.
         """
         if self._ntpts < num_neighbors:
-            self._raise('WeightedInterpolant does not have sufficient '
-                        'training data to use num_neighbors={0}, only {1} points'
-                        ' available.'.format(num_neighbors, self._ntpts),
-                        exc_type=ValueError)
+            raise ValueError('WeightedInterpolant does not have sufficient '
+                             f'training data to use num_neighbors={num_neighbors}, '
+                             f'only {self._ntpts} points available.')
 
         if dist_eff == 0:
             # If default, use #dims + 1
@@ -108,7 +107,7 @@ class WeightedInterpolator(NNBase):
         ----------
         prediction_points : ndarray
             Points at which interpolation is done.
-        num_neighbors :  int
+        num_neighbors : int
             Number of neighbors to use.
         dist_eff : float
             Exponent used for the distance weighting. Using dist_eff=0 will default to
@@ -120,10 +119,9 @@ class WeightedInterpolator(NNBase):
             Gradient values at the prediction points.
         """
         if self._ntpts < num_neighbors:
-            self._raise('WeightedInterpolant does not have sufficient '
-                        'training data to use num_neighbors={0}, only {1} points'
-                        ' available.'.format(num_neighbors, self._ntpts),
-                        exc_type=ValueError)
+            raise ValueError('WeightedInterpolant does not have sufficient '
+                             f'training data to use num_neighbors={num_neighbors}, '
+                             f'only {self._ntpts} points available.')
 
         if dist_eff == 0:
             # If default, use #dims + 1
