@@ -3,7 +3,6 @@ from contextlib import contextmanager
 import os
 import re
 import sys
-import math
 import warnings
 import unittest
 from fnmatch import fnmatchcase
@@ -17,13 +16,12 @@ except ImportError:
     from collections import Iterable
 
 import numbers
-import json
-import importlib
 
 import numpy as np
 import openmdao
 
 from openmdao.core.constants import INT_DTYPE
+from openmdao.warnings import issue_warning, _warn_simple_format, warn_deprecation
 
 # Certain command line tools can make use of this to allow visualization of models when errors
 # are present that would normally cause setup to abort.
@@ -79,13 +77,13 @@ def conditional_error(msg, exc=RuntimeError, category=UserWarning):
     ----------
     msg : str
         The error/warning message.
-    exc : exception class
+    exc : Exception class
         This exception class is used to create the exception to be raised.
     category : warning class
         This category is the class of warning to be issued.
     """
     if ignore_errors():
-        simple_warning(msg, category=category)
+        issue_warning(msg, category=category)
     else:
         raise exc(msg)
 
@@ -108,27 +106,6 @@ def ignore_errors_context(flag=True):
         ignore_errors(save)
 
 
-def warn_deprecation(msg):
-    """
-    Raise a warning and prints a deprecation message to stdout.
-
-    Parameters
-    ----------
-    msg : str
-        Message that will be printed to stdout.
-    """
-    # Deprecation warnings need to be printed regardless of debug level
-    warnings.simplefilter('always', DeprecationWarning)
-
-    # note, stack level 3 should take us back to original caller.
-    simple_warning(msg, DeprecationWarning, stacklevel=3)
-    warnings.simplefilter('ignore', DeprecationWarning)
-
-
-def _warn_simple_format(message, category, filename, lineno, file=None, line=None):
-    return '%s:%s: %s:%s\n' % (filename, lineno, category.__name__, message)
-
-
 def simple_warning(msg, category=UserWarning, stacklevel=2):
     """
     Display a simple warning message without the annoying extra line showing the warning call.
@@ -142,6 +119,7 @@ def simple_warning(msg, category=UserWarning, stacklevel=2):
     stacklevel : int
         Number of levels up the stack to identify as the warning location.
     """
+    warn_deprecation('simple_warning is deprecated.  Use openmdao.warnings.issue_warning instead.')
     old_format = warnings.formatwarning
     warnings.formatwarning = _warn_simple_format
     try:
@@ -150,93 +128,6 @@ def simple_warning(msg, category=UserWarning, stacklevel=2):
         warnings.formatwarning = old_format
 
 
-class reset_warning_registry(object):
-    """
-    Context manager which archives & clears warning registry for duration of context.
-
-    From https://bugs.python.org/file40031/reset_warning_registry.py
-
-    Attributes
-    ----------
-    _pattern : regex pattern
-        Causes manager to only reset modules whose names match this pattern. defaults to ``".*"``.
-    """
-
-    #: regexp for filtering which modules are reset
-    _pattern = None
-
-    #: dict mapping module name -> old registry contents
-    _backup = None
-
-    def __init__(self, pattern=None):
-        """
-        Initialize all attributes.
-
-        Parameters
-        ----------
-        pattern : regex pattern
-            Causes manager to only reset modules whose names match pattern. defaults to ``".*"``.
-        """
-        self._pattern = re.compile(pattern or ".*")
-
-    def __enter__(self):
-        """
-        Enter the runtime context related to this object.
-
-        Returns
-        -------
-        reset_warning_registry
-            This context manager.
-
-        """
-        # archive and clear the __warningregistry__ key for all modules
-        # that match the 'reset' pattern.
-        pattern = self._pattern
-        backup = self._backup = {}
-        for name, mod in list(sys.modules.items()):
-            if pattern.match(name):
-                reg = getattr(mod, "__warningregistry__", None)
-                if reg:
-                    backup[name] = reg.copy()
-                    reg.clear()
-        return self
-
-    def __exit__(self, exc_type, exc_value, traceback):
-        """
-        Exit the runtime context related to this object.
-
-        Parameters
-        ----------
-        exc_type : Exception class
-            The type of the exception.
-        exc_value : Exception instance
-            The exception instance raised.
-        traceback : regex pattern
-            Traceback object.
-        """
-        # restore warning registry from backup
-        modules = sys.modules
-        backup = self._backup
-        for name, content in backup.items():
-            mod = modules.get(name)
-            if mod is None:
-                continue
-            reg = getattr(mod, "__warningregistry__", None)
-            if reg is None:
-                setattr(mod, "__warningregistry__", content)
-            else:
-                reg.clear()
-                reg.update(content)
-
-        # clear all registry entries that we didn't archive
-        pattern = self._pattern
-        for name, mod in list(modules.items()):
-            if pattern.match(name) and name not in backup:
-                reg = getattr(mod, "__warningregistry__", None)
-                if reg:
-                    reg.clear()
-
-
 def ensure_compatible(name, value, shape=None, indices=None):
     """
     Make value compatible with the specified shape or the shape of indices.
@@ -716,84 +607,6 @@ def do_nothing_context():
     return contextmanager(nothing)()
 
 
-def _byteify(data, ignore_dicts=False):
-    """
-    Convert any unicode items in a data structure to bytes (object_hook for json load/loads).
-
-    Credit: Mirec Miskuf
-    stackoverflow.com/questions/956867/how-to-get-string-objects-instead-of-unicode-from-json
-
-    Parameters
-    ----------
-    data : any data item or structure
-        the data to be converted
-    ignore_dicts : bool
-        a flag to prevent recursion on dicts that have already been byteified.
-        False when object_hook passes a new dict to byteify, True at all other times.
-
-    Returns
-    -------
-    data item or structure
-        data item or structure with unicode converted to bytes
-    """
-    # if this is a unicode string, return its string representation
-    if isinstance(data, unicode):
-        return data.encode('utf-8')
-
-    # if this is a list of values, return list of byteified values
-    if isinstance(data, list):
-        return [_byteify(item, ignore_dicts=True) for item in data]
-
-    # if this is a dictionary, return dictionary of byteified keys and values
-    # but only if we haven't already byteified it
-    if isinstance(data, dict) and not ignore_dicts:
-        return {
-            _byteify(key, ignore_dicts=True): _byteify(value, ignore_dicts=True)
-            for key, value in data.iteritems()
-        }
-
-    # if it's anything else, return it in its original form
-    return data
-
-
-def json_load_byteified(file_handle):
-    """
-    Load data from a JSON file, converting unicode to bytes if Python version is 2.x.
-
-    Intended for use only with Python 2.x, behaves the same as json.load() under Python 3.x.
-
-    Parameters
-    ----------
-    file_handle : file
-        file containing the data to be converted
-
-    Returns
-    -------
-    data item or structure
-        data item or structure with unicode converted to bytes
-    """
-    return json.load(file_handle)
-
-
-def json_loads_byteified(json_str):
-    """
-    Load data from a JSON string, converting unicode to bytes if Python version is 2.x.
-
-    Intended for use only with Python 2.x, behaves the same as json.loads() under Python 3.x.
-
-    Parameters
-    ----------
-    json_str : str
-        text string containing json encoded data
-
-    Returns
-    -------
-    data item or structure
-        data item or structure with unicode converted to bytes
-    """
-    return json.loads(json_str)
-
-
 def remove_whitespace(s, right=False, left=False):
     """
     Remove white-space characters from the given string.
@@ -1160,7 +973,18 @@ def _slice_indices(slicer, arr_size, arr_shape):
     array
         Returns the sliced indices.
     """
-    return np.arange(arr_size, dtype=INT_DTYPE).reshape(arr_shape)[slicer]
+    if isinstance(slicer, slice):
+        # for a simple slice we can use less memory
+        start, stop, step = slicer.start, slicer.stop, slicer.step
+        if start is None:
+            start = 0
+        if stop is None:
+            stop = arr_size
+        if step is None:
+            step = 1
+        return np.arange(start, stop, step, dtype=INT_DTYPE).reshape(arr_shape)
+    else:
+        return np.arange(arr_size, dtype=INT_DTYPE).reshape(arr_shape)[slicer]
 
 
 def _prom2ivc_src_name_iter(prom_dict):
@@ -1188,6 +1012,8 @@ def _prom2ivc_src_item_iter(prom_dict):
     """
     Yield items from prom_dict with promoted input names converted to ivc source names.
 
+    The result is that all names are absolute.
+
     Parameters
     ----------
     prom_dict : dict
@@ -1354,9 +1180,9 @@ def shape2tuple(shape):
 
 def get_connection_owner(system, tgt):
     """
-    Return (owner, promoted_src, promoted_tgt) for the given connected source and target.
+    Return (owner, promoted_src, promoted_tgt) for the given connected target.
 
-    Note: this is not speedy.  It's intended for use only in error messages.
+    Note : this is not speedy.  It's intended for use only in error messages.
 
     Parameters
     ----------
