@@ -8,15 +8,9 @@ import networkx as nx
 
 import numpy as np
 
-try:
-    from IPython.display import IFrame, display, HTML
-except ImportError:
-    IFrame = display = None
-
 from openmdao.components.exec_comp import ExecComp
 from openmdao.components.meta_model_structured_comp import MetaModelStructuredComp
 from openmdao.components.meta_model_unstructured_comp import MetaModelUnStructuredComp
-from openmdao.core.notebook_mode import notebook, colab
 from openmdao.core.explicitcomponent import ExplicitComponent
 from openmdao.core.indepvarcomp import IndepVarComp
 from openmdao.core.parallel_group import ParallelGroup
@@ -28,11 +22,13 @@ from openmdao.drivers.doe_driver import DOEDriver
 from openmdao.recorders.case_reader import CaseReader
 from openmdao.solvers.nonlinear.newton import NewtonSolver
 from openmdao.utils.class_util import overrides_method
-from openmdao.utils.general_utils import simple_warning, default_noraise
+from openmdao.utils.general_utils import default_noraise
 from openmdao.utils.mpi import MPI
+from openmdao.utils.notebook_utils import notebook, display, HTML, IFrame, colab
 from openmdao.visualization.html_utils import read_files, write_script, DiagramWriter
-from openmdao.utils.general_utils import warn_deprecation
+from openmdao.warnings import issue_warning, warn_deprecation
 from openmdao.core.constants import _UNDEFINED
+from openmdao import __version__ as openmdao_version
 
 _IND = 4  # HTML indentation (spaces)
 
@@ -344,7 +340,9 @@ def _get_viewer_data(data_source, case_id=None):
     Parameters
     ----------
     data_source : <Problem> or <Group> or str
-        A Problem or Group or case recorder file name containing the model or model data.
+        A Problem or Group or case recorder filename containing the model or model data.
+        If the case recorder file from a parallel run has separate metadata, the
+        filenames can be specified with a comma, e.g.: case.sql_0,case.sql_meta
 
     case_id : int or str or None
         Case name or index of case in SQL file.
@@ -358,7 +356,7 @@ def _get_viewer_data(data_source, case_id=None):
         root_group = data_source.model
 
         if not isinstance(root_group, Group):
-            simple_warning("The model is not a Group, viewer data is unavailable.")
+            issue_warning("The model is not a Group, viewer data is unavailable.")
             return {}
 
         driver = data_source.driver
@@ -382,11 +380,15 @@ def _get_viewer_data(data_source, case_id=None):
             driver_opt_settings = None
         else:
             # this function only makes sense when it is at the root
-            simple_warning(f"Viewer data is not available for sub-Group '{data_source.pathname}'.")
+            issue_warning(f"Viewer data is not available for sub-Group '{data_source.pathname}'.")
             return {}
 
     elif isinstance(data_source, str):
-        cr = CaseReader(data_source)
+        if ',' in data_source:
+            filenames = data_source.split(',')
+            cr = CaseReader(filenames[0], metadata_filename=filenames[1])
+        else:
+            cr = CaseReader(data_source)
 
         data_dict = cr.problem_metadata
 
@@ -570,7 +572,8 @@ def n2(data_source, outfile='n2.html', case_id=None, show_browser=True, embeddab
         'd3': 'd3.v5.min',
         'awesomplete': 'awesomplete',
         'vk_beautify': 'vkBeautify',
-        'pako_inflate': 'pako_inflate.min'
+        'pako_inflate': 'pako_inflate.min',
+        'json5': 'json5_2.2.0.min'
     }
     libs = read_files(lib_dct.values(), libs_dir, 'js')
     src_names = \
@@ -637,6 +640,7 @@ def n2(data_source, outfile='n2.html', case_id=None, show_browser=True, embeddab
     h.insert('{{logo_png}}', logo_png)
     h.insert('{{waiting_icon}}', waiting_icon)
     h.insert('{{n2toolbar_png}}', n2toolbar_png)
+    h.insert('{{om_version}}', openmdao_version)
 
     for k, v in lib_dct.items():
         h.insert('{{{}_lib}}'.format(k), write_script(libs[v], indent=_IND))
@@ -652,8 +656,9 @@ def n2(data_source, outfile='n2.html', case_id=None, show_browser=True, embeddab
 
     if notebook:
         # display in Jupyter Notebook
+        outfile = os.path.relpath(outfile)
         if not colab:
-            display(IFrame(src=outfile, width=1000, height=1000))
+            display(IFrame(src=outfile, width="100%", height=700))
         else:
             display(HTML(outfile))
     elif show_browser:
